==> igniteui-react-charts-16.6.8.tgz: package/ES2015/AbsoluteVolumeOscillatorIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { IShortPeriodLongPeriod_$type } from "./IShortPeriodLongPeriod";
import { AbsoluteVolumeOscillatorIndicatorStrategy } from "./AbsoluteVolumeOscillatorIndicatorStrategy";
import { typeGetValue, markType } from "igniteui-react-core/ES2015/type";
/**
 * @hidden
 */
export class AbsoluteVolumeOscillatorIndicator extends StrategyBasedIndicator {
    get_p5() {
        return new AbsoluteVolumeOscillatorIndicatorStrategy();
    }
    get p5() {
        return this.get_p5();
    }
    get_qi() {
        return AbsoluteVolumeOscillatorIndicator.$;
    }
    get qi() {
        return this.get_qi();
    }
    get shortPeriod() {
        return typeGetValue(this.c(AbsoluteVolumeOscillatorIndicator.qr));
    }
    set shortPeriod(a) {
        this.h(AbsoluteVolumeOscillatorIndicator.qr, a);
    }
    qd() {
        return this.shortPeriod;
    }
    get longPeriod() {
        return typeGetValue(this.c(AbsoluteVolumeOscillatorIndicator.qq));
    }
    set longPeriod(a) {
        this.h(AbsoluteVolumeOscillatorIndicator.qq, a);
    }
    qa() {
        return this.longPeriod;
    }
}
AbsoluteVolumeOscillatorIndicator.$t = markType(AbsoluteVolumeOscillatorIndicator, 'AbsoluteVolumeOscillatorIndicator', StrategyBasedIndicator.$, [IShortPeriodLongPeriod_$type]);
AbsoluteVolumeOscillatorIndicator.qr = StrategyBasedIndicator.qp(10, AbsoluteVolumeOscillatorIndicator.$);
AbsoluteVolumeOscillatorIndicator.qq = StrategyBasedIndicator.ql(30, AbsoluteVolumeOscillatorIndicator.$);

==> igniteui-react-charts-16.11.1.tgz: package/ES2015/AbsoluteVolumeOscillatorIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { IShortPeriodLongPeriod_$type } from "./IShortPeriodLongPeriod";
import { AbsoluteVolumeOscillatorIndicatorStrategy } from "./AbsoluteVolumeOscillatorIndicatorStrategy";
import { typeGetValue, markType } from "igniteui-react-core/ES2015/type";
/**
 * @hidden
 */
export class AbsoluteVolumeOscillatorIndicator extends StrategyBasedIndicator {
    get_qc() {
        return new AbsoluteVolumeOscillatorIndicatorStrategy();
    }
    get qc() {
        return this.get_qc();
    }
    get_qp() {
        return AbsoluteVolumeOscillatorIndicator.$;
    }
    get qp() {
        return this.get_qp();
    }
    get shortPeriod() {
        return typeGetValue(this.c(AbsoluteVolumeOscillatorIndicator.qy));
    }
    set shortPeriod(a) {
        this.h(AbsoluteVolumeOscillatorIndicator.qy, a);
    }
    qk() {
        return this.shortPeriod;
    }
    get longPeriod() {
        return typeGetValue(this.c(AbsoluteVolumeOscillatorIndicator.qx));
    }
    set longPeriod(a) {
        this.h(AbsoluteVolumeOscillatorIndicator.qx, a);
    }
    qh() {
        return this.longPeriod;
    }
}
AbsoluteVolumeOscillatorIndicator.$t = markType(AbsoluteVolumeOscillatorIndicator, 'AbsoluteVolumeOscillatorIndicator', StrategyBasedIndicator.$, [IShortPeriodLongPeriod_$type]);
AbsoluteVolumeOscillatorIndicator.qy = StrategyBasedIndicator.qw(10, AbsoluteVolumeOscillatorIndicator.$);
AbsoluteVolumeOscillatorIndicator.qx = StrategyBasedIndicator.qs(30, AbsoluteVolumeOscillatorIndicator.$);
